import React, {Component} from "react";
import {
    Button, Dialog,
    DialogActions,
    DialogContent,
    DialogContentText,
    DialogTitle,
    Grid, ListItemAvatar,
    Snackbar,
    Typography,
    Avatar, ListItemText, ListItem, List
} from "@mui/material";
import NfcIcon from '@mui/icons-material/Nfc';
import AddCardIcon from '@mui/icons-material/AddCard';
import PersonAddIcon from '@mui/icons-material/PersonAdd';
import PersonRemoveIcon from '@mui/icons-material/PersonRemove';
import ImageIcon from '@mui/icons-material/Image';
import WorkIcon from '@mui/icons-material/Work';
import BeachAccessIcon from '@mui/icons-material/BeachAccess';

import GameHandler from "./GameHandler";
import {NFCCard} from "../RawConstants";

interface GameState {
    snackMsg: string,
    helpDialog: boolean
}

export default class GameSetup extends Component<{}, GameState> {
    constructor(props: {}) {
        super(props);
        this.state = {
            snackMsg: "",
            helpDialog: true
        }
    }


    componentDidMount() {
        setTimeout(() => {
            this.setState((prevState) => ({
                ...prevState,
                helpDialog: false,
                snackMsg: "Zum hinzufügen von Spielern, NFC-Karte an das Lesegerät halten!",
            }))
        }, 15000);

        GameHandler.attachNFCHandler((card: NFCCard) => {

        })
    }

    componentWillUnmount() {
        GameHandler.detachNFCHandler();
    }

    render() {
        return <div className="gameSetup">
            <Snackbar
                open={!!this.state.snackMsg}
                autoHideDuration={8000}
                onClose={() => {
                    this.setState(prevState => ({
                        ...prevState,
                        snackMsg: ""
                    }))
                }}
                message={this.state.snackMsg}
            />
            <Dialog
                open={this.state.helpDialog}
                onClose={() => {
                    this.setState((prevState) => ({
                        ...prevState,
                        helpDialog: false
                    }))
                }}
                aria-labelledby="alert-dialog-title"
                aria-describedby="alert-dialog-description"
            >
                <DialogTitle id="alert-dialog-title">
                    Spielerkarte auf Gerät legen! <AddCardIcon/>
                </DialogTitle>
                <DialogContent>
                    <DialogContentText id="alert-dialog-description">
                        Um eine Figur zum Spiel hinzuzufügen, musst du die NFC-Spielerkarte an den Kartenleser
                        halten. <br/><br/>
                        Ein kurzes Berühren reicht aus, schon sollte der Spieler in der Tabelle auftauchen! <PersonAddIcon/>
                    </DialogContentText>
                </DialogContent>
                <DialogActions>
                    <Button onClick={() => this.setState((prevState) => ({
                        ...prevState,
                        helpDialog: false
                    }))}>
                        Okay</Button>
                </DialogActions>
            </Dialog>


            <Typography variant="h2" sx={{mb: 2}}>Wer spielt mit?</Typography>
            <Grid container spacing={1}>
                <Grid item xs={4}></Grid>
                <Grid justifyContent="center" alignItems="center" item xs={"auto"}>
                    <List sx={{ width: '100%', minWidth: '40%', bgcolor: 'background.paper', border: "1px solid black", borderRadius: "5px" }}>
                        <ListItem>
                            <ListItemAvatar>
                                <Avatar>
                                    <ImageIcon />
                                </Avatar>
                            </ListItemAvatar>
                            <ListItemText primary="Photos" secondary="Jan 9, 2014" />
                        </ListItem>
                        <ListItem>
                            <ListItemAvatar>
                                <Avatar>
                                    <WorkIcon />
                                </Avatar>
                            </ListItemAvatar>
                            <ListItemText primary="Work" secondary="Jan 7, 2014" />
                        </ListItem>
                        <ListItem>
                            <ListItemAvatar>
                                <Avatar>
                                    <BeachAccessIcon />
                                </Avatar>
                            </ListItemAvatar>
                            <ListItemText primary="Vacation" secondary="July 20, 2014" />
                        </ListItem>
                    </List>
                </Grid>
            </Grid>
        </div>
    }

    }